using System;
using Server;
using Server.Mobiles;
using Server.Spells;

namespace Server.Items
{
	public class BoneGolemTorso : Item
	{
		[Constructable]
		public BoneGolemTorso() : base( 0x144F )
		{
			Weight = 8.0;
			Name = "Bone Golem Torso";
		}

		public BoneGolemTorso( Serial serial ) : base( serial )
		{
		}

		public override void OnDoubleClick( Mobile from )
		{
			if ( !IsChildOf( from.Backpack ) )
			{
				from.SendLocalizedMessage( 1042001 ); // That must be in your pack for you to use it.
				return;
			}

			double necromancySkill = from.Skills[SkillName.Necromancy].Value;

			if ( necromancySkill < 85.0 )
			{
				from.SendMessage( "You do not have the knowledge required to attempt this." );
				return;
			}
			else if ( (from.Followers + 2) > from.FollowersMax )
			{
				from.SendLocalizedMessage( 1049607 ); // You have too many followers to control that creature.
				return;
			}

			double scalar;

			if ( necromancySkill >= 95.0 )
				scalar = 1.0;
			else if ( necromancySkill >= 85.0 )
				scalar = 0.9;
			else if ( necromancySkill >= 75.0 )
				scalar = 0.8;
			else
				scalar = 0.5;

			Container pack = from.Backpack;

			if ( pack == null )
				return;

			int res = pack.ConsumeTotal(
				new Type[]
				{
					typeof( BoneGolemArms ),
					typeof( BoneGolemLegs ),
					typeof( BoneGolemHands ),
					typeof( BoneGolemHead )
				},
				new int[]
				{
					1,
					1,
					1,
					1

				} );

			switch ( res )
			{
				case 0:
				{
					from.SendMessage( "The arms are missing from the Golem." );
					break;
				}
				case 1:
				{
					from.SendMessage( "You need the legs to complete the Golem." );
					break;
				}
				case 2:
				{
					from.SendMessage( "You must have the hands to finish the Golem." );
					break;
				}
				case 3:
				{
					from.SendMessage( "A head is required to complete construction of the Golem." );
					break;
				}

				default:
				{
					BoneGolem m = new BoneGolem( true, scalar );

					if ( m.SetControlMaster( from ) )
					{
						Delete();

						m.MoveToWorld( from.Location, from.Map );
						from.PlaySound( 0x241 );
					}

					break;
				}
			}
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}
	}
}