using System;
using Server.Items;

namespace Server.Mobiles
{
	[CorpseName( "a flesh BoneGolem corpse" )]
	public class BoneGolem : BaseCreature
	{
		public override WeaponAbility GetWeaponAbility()
		{
			return WeaponAbility.ArmorIgnore;
		}

		public override bool IsScaredOfScaryThings{ get{ return false; } }
		public override bool IsScaryToPets{ get{ return true; } }

		public override bool IsBondable{ get{ return false; } }

		[Constructable]
		public BoneGolem() : this( false, 1.0 )
		{
		}

		[Constructable]
		public BoneGolem( bool summoned, double scalar ) : base( AIType.AI_Melee, FightMode.Closest, 10, 1, 0.4, 0.8 )
		{
			Name = "a Bone Golem";
			Body = 50;
			BaseSoundID = 0x48D;

			SetStr( (int)(100*scalar), (int)(140*scalar) );
			SetDex( (int)(90*scalar), (int)(170*scalar) );
			SetInt( (int)(40*scalar), (int)(40*scalar) );

			SetHits( (int)(106*scalar), (int)(120*scalar) );

			SetDamage( (int)(13*scalar), (int)(18*scalar) );

			SetDamageType( ResistanceType.Physical, 100 );

			SetResistance( ResistanceType.Physical, (int)(30*scalar), (int)(40*scalar) );

			if ( summoned )
				SetResistance( ResistanceType.Fire, (int)(5*scalar), (int)(10*scalar) );
			else
				SetResistance( ResistanceType.Fire, (int)(0*scalar) );

			SetResistance( ResistanceType.Cold, (int)(40*scalar), (int)(50*scalar) );
			SetResistance( ResistanceType.Poison, (int)(60*scalar), (int)(70*scalar) );
			SetResistance( ResistanceType.Energy, (int)(20*scalar), (int)(35*scalar) );

			SetSkill( SkillName.MagicResist, (40.1*scalar), (60.0*scalar) );
			SetSkill( SkillName.Tactics, (55.1*scalar), (80.0*scalar) );
			SetSkill( SkillName.Wrestling, (60.1*scalar), (70.0*scalar) );
			SetSkill( SkillName.Anatomy, (55.1*scalar), (80.0*scalar) );

			if ( summoned )
			{
				Fame = 100;
				Karma = 100;
			}
			else
			{
				Fame = 100;
				Karma = 100;
			}

			VirtualArmor = 20;

			ControlSlots = 2;

			switch ( Utility.Random( 4 ))
			{
				case 0: PackItem( new BoneGolemHead() ); break;
				case 1: PackItem( new BoneGolemArms() ); break;
				case 2: PackItem( new BoneGolemLegs() ); break;
				case 3: PackItem( new BoneGolemHands() ); break;

			}
		
		}

		public override bool DeleteOnRelease{ get{ return false; } }

		public override bool AutoDispel{ get{ return !Controled; } }

		public override void OnGaveMeleeAttack( Mobile defender )
		{
			base.OnGaveMeleeAttack( defender );

			if ( 0.2 > Utility.RandomDouble() )
				defender.Combatant = null;
		}

		public override void OnDamage( int amount, Mobile from, bool willKill )
		{
			if ( Controled || Summoned )
			{
				Mobile master = ( this.ControlMaster );

				if ( master == null )
					master = this.SummonMaster;

				if ( master != null && master.Player && master.Map == this.Map && master.InRange( Location, 20 ) )
				{
					if ( master.Mana >= amount )
					{
						master.Mana -= amount;
					}
					else
					{
						amount -= master.Mana;
						master.Mana = 0;
						master.Damage( amount );
					}
				}
			}

			base.OnDamage( amount, from, willKill );
		}

		public override bool BardImmune{ get{ return true; } }
		public override Poison PoisonImmune{ get{ return Poison.Lethal; } }
		public override bool CanRummageCorpses{ get{ return true; } }

		public BoneGolem( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}