using System;
using Server.Items;
using Server.Mobiles;

namespace Server.Engines.Craft
{
	public class DefNecroGolem : CraftSystem
	{
		public override SkillName MainSkill
		{
			get	{ return SkillName.Necromancy;	}
		}

		public override int GumpTitleNumber
		{
			get { return 0; } // Use String
		}

		public override string GumpTitleString
		{
			get { return "<basefont color=#FFFFFF><CENTER>NecroGolem Menu</CENTER></basefont>"; } 
		}

		private static CraftSystem m_CraftSystem;

		public static CraftSystem CraftSystem
		{
			get
			{
				if ( m_CraftSystem == null )
					m_CraftSystem = new DefNecroGolem();

				return m_CraftSystem;
			}
		}

		public override double GetChanceAtMin( CraftItem item )
		{
			return 0.5; // 50%
		}

		private DefNecroGolem() : base( 1, 1, 1.25 )// base( 1, 1, 3.0 )
		{
		}

		public override int CanCraft( Mobile from, BaseTool tool, Type itemType )
		{
			if ( tool.Deleted || tool.UsesRemaining < 0 )
				return 1044038; // You have worn out your tool!

			return 0;
		}

		public override void PlayCraftEffect( Mobile from )
		{
			// no animation
			//if ( from.Body.Type == BodyType.Human && !from.Mounted )
			//	from.Animate( 9, 5, 1, true, false, 0 );

			from.PlaySound( 0x248 );
		}

		public override int PlayEndingEffect( Mobile from, bool failed, bool lostMaterial, bool toolBroken, int quality, bool makersMark, CraftItem item )
		{
			if ( toolBroken )
				from.SendLocalizedMessage( 1044038 ); // You have worn out your tool

			if ( failed )
			{
				if ( lostMaterial )
					return 1044043; // You failed to create the item, and some of your materials are lost.
				else
					return 1044157; // You failed to create the item, but no materials were lost.
			}
			else
			{
				if ( quality == 0 )
					return 502785; // You were barely able to make this item.  It's quality is below average.
				else if ( quality == 2 )
					return 1044155; // You create an exceptional quality item.
				else				
					return 1044154; // You create the item.
			}
		}

		public override void InitCraftList()
		{
			int index = -1;

			//Flesh Golems
			index = AddCraft( typeof(LesserFleshGolemTorso ), "Flesh Golems", "Lesser Flesh Golem Torso", SkillName.Necromancy, 70.0, 85.0, typeof( Torso ), "Torso", 1 );
			AddSkill( index, SkillName.Anatomy, 75.0, 80.0 );	
			AddRes( index, typeof( ArcaneGem ), "Arcane Gem", 1 );
			AddRes( index, typeof( SpoolOfThread ), "Spool of Thread", 1 );

			index = AddCraft( typeof(FleshGolemTorso ), "Flesh Golems", "Flesh Golem Torso", SkillName.Necromancy, 85.0, 100.0, typeof( Torso ), "Torso", 1 );
			AddSkill( index, SkillName.Anatomy, 85.0, 90.0 );
			AddRes( index, typeof( ArcaneGem ), "Arcane Gems", 5 );
			AddRes( index, typeof( SpoolOfThread ), "Spool of Thread", 1 );

                        index = AddCraft( typeof( GreaterFleshGolemTorso ), "Flesh Golems", "Greater Flesh Golem Torso", SkillName.Necromancy, 100.0, 120.0, typeof( Torso ), "Torso", 1 );
			AddSkill( index, SkillName.Anatomy, 95.0, 100.0 );
			AddRes( index, typeof( ArcaneGem ), "Arcane Gems", 10 );
			AddRes( index, typeof( SpoolOfThread ), "Spool of Thread", 1 );

			//Bone Golems
			index = AddCraft( typeof( BoneGolemTorso ), "Bone Golems", "Bone Golem Torso", SkillName.Necromancy, 75.0, 95.0, typeof( Bone ), "Bones", 20 );
			AddRes( index, typeof( ArcaneGem ), "Arcane Gems", 6 );
			index = AddCraft( typeof( BoneGolemArms ), "Bone Golems", "Bone Golem Arms", SkillName.Necromancy, 75.0, 90.0, typeof( Bone ), "Bones", 10 );
			AddRes( index, typeof( ArcaneGem ), "Arcane Gems", 2 );
			index = AddCraft( typeof( BoneGolemLegs ), "Bone Golems", "Bone Golem Legs", SkillName.Necromancy, 75.0, 90.0, typeof( Bone ), "Bones", 16 );
			AddRes( index, typeof( ArcaneGem ), "Arcane Gems", 4 );
			index = AddCraft( typeof( BoneGolemHands ), "Bone Golems", "Bone Golem Hands", SkillName.Necromancy, 75.0, 90.0, typeof( Bone ), "Bones", 4 );
			AddRes( index, typeof( ArcaneGem ), "Arcane Gem", 1 );
			index = AddCraft( typeof( BoneGolemHead ), "Bone Golems", "Bone Golem Head", SkillName.Necromancy, 80.0, 95.0, typeof( Bone ), "Bones", 8 );
			AddRes( index, typeof( ArcaneGem ), "Arcange Gems", 2 );
			AddRes( index, typeof( Ruby ), "Rubies", 2 );
		}

}	}
